import React, { Fragment } from 'react';
import {
	Table,
	Row,
	Form,
	Button,
	Input,
	message,
	PageHeader,
	Typography,
	Badge,
	Space,
} from 'antd';
import { ColumnProps } from 'antd/lib/table';
import { SearchOutlined, PushpinOutlined } from '@ant-design/icons';
import {
	useWaitApplyComanyList,
	useUpdateCompany,
} from '../../services/company';
import ReviewPopup from './components/reviewPopup';
import DrawerToDetail from './components/detailDrawer';

const { Text } = Typography;
const expandDataRows = [
	{
		title: '公司名称',
		dataIndex: 'name',
		span: 2,
	},
	{
		title: '统一社会信用代码',
		dataIndex: 'social_code',
		span: 1,
	},
	{
		title: '公司地址',
		dataIndex: 'addr',
		span: 1,
	},

	{
		title: '法定代表人',
		dataIndex: 'legal_person',
		span: 1,
	},

	{
		title: '证件号',
		dataIndex: 'id_cert',
		span: 1,
	},
	{
		title: '业务联系人',
		dataIndex: 'business_contact',
		span: 1,
	},
	{
		title: '业务联系人电话',
		dataIndex: 'business_contact_phone',
		span: 1,
	},
	{
		title: '业务负责人',
		dataIndex: 'business_responsible',
		span: 1,
	},
	{
		title: '业务负责人电话',
		dataIndex: 'business_responsible_phone',
		span: 1,
	},
	{
		title: '紧急联系人',
		dataIndex: 'emergency_contact',
		span: 1,
	},
	{
		title: '紧急联系人电话',
		dataIndex: 'emergency_contact_phone',
		span: 1,
	},

	{
		name: '营业执照',
		dataIndex: 'business_license',
		img: true,
		span: 2,
	},
	{
		title: '审核状态',
		dataIndex: 'statusText',
		span: 1,
	},
	{
		title: '审批时间',
		dataIndex: 'approve_time',
		span: 1,
	},
	{
		title: '审批回复',
		dataIndex: 'feedback',
		span: 2,
	},
];

/**
 * @description 审批 企业列表
 * @param props
 */
const supplierApplyList: React.FC = (props) => {
	const [applyModalState, setApplyModalState] = React.useState<{
		modalVisible: boolean;
		id?: string;
	}>({
		modalVisible: false,
	});
	const [detailDrawerState, changeDrawerState] = React.useState<{
		visible: boolean;
		values?: any;
	}>({
		visible: false,
	});
	const [searchState, setSearchState] = React.useState({
		filter: '',
		page: 1,
	});
	const [applyListState, requestApplyList] = useWaitApplyComanyList();
	React.useEffect(() => {
		requestApplyList(searchState);
	}, [searchState]);
	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};

	const [updatState, requestApply] = useUpdateCompany();
	const handleSwitchApplyModalVisible = (id = '') => {
		setApplyModalState((preState) => ({
			...preState,
			modalVisible: !preState.modalVisible,
			id,
		}));
	};

	const handleApply = (data) => {
		if (updatState.loading) {
			return;
		}
		requestApply({
			...data,
			id: applyModalState.id as string,
		})
			.then(() => {
				message.success('审批成功');
				handleSwitchApplyModalVisible();
				requestApplyList(applyListState.deepData);
			})
			.catch((error) => {
				message.error(error.message);
			});
	};

	const columns: ColumnProps<any>[] = [
		{
			title: '供应商',
			dataIndex: 'name',
			key: 'name',
		},
		{
			title: '社会统一信用代码',
			dataIndex: 'social_code',
			key: 'social_code',
		},
		{
			title: '业务联系人',
			dataIndex: 'business_contact',
			key: 'business_contact',
		},
		{
			title: '业务联系人电话',
			dataIndex: 'business_contact_phone',
			key: 'business_contact_phone',
		},
		{
			title: '申请时间',
			dataIndex: 'apply_time',
			key: 'apply_time',
		},
		{
			title: '审核状态',
			dataIndex: 'statusText',
			key: 'statusText',
			render: (dataValue, record) => {
				const isRefuse = record.status === 2;
				return (
					<Fragment>
						<Badge status={isRefuse ? 'error' : 'processing'}></Badge>
						<Text type={isRefuse ? 'danger' : 'secondary'}>{dataValue}</Text>
					</Fragment>
				);
			},
		},
		{
			title: '操作',
			render: (record) => {
				const isRefuse = record.status === 2;
				return (
					<Space>
						<Button
							disabled={isRefuse}
							icon={<PushpinOutlined />}
							onClick={() => handleSwitchApplyModalVisible(record.id)}>
							审核
						</Button>
						<Button
							type='primary'
							onClick={() => {
								changeDrawerState({ visible: true, values: record });
							}}>
							详情
						</Button>
					</Space>
				);
			},
		},
	];

	return (
		<React.Fragment>
			<PageHeader title='审批-企业列表' style={{ paddingLeft: 0 }}></PageHeader>
			<div>
				<Form layout='inline' onFinish={onSearch}>
					<Form.Item name='filter'>
						关键字：
						<Input
							style={{ width: 280 }}
							placeholder='企业名称或社会统一信用代码'></Input>
					</Form.Item>
					<Button
						type='primary'
						htmlType='submit'
						icon={<SearchOutlined></SearchOutlined>}>
						搜索
					</Button>
				</Form>
			</div>
			<Table
				columns={columns}
				loading={applyListState.loading}
				rowKey={(record) => record.id}
				pagination={{
					hideOnSinglePage: true,
					total: applyListState.total,
					current: applyListState.page,
					onChange: (page) => {
						setSearchState((preState) => ({ ...preState, page }));
					},
				}}
				dataSource={applyListState.dataSource}></Table>
			<ReviewPopup
				onSubmit={handleApply}
				onCancel={() => handleSwitchApplyModalVisible()}
				visible={applyModalState.modalVisible}></ReviewPopup>
			{detailDrawerState.values ? (
				<DrawerToDetail
					dataRows={expandDataRows}
					values={detailDrawerState.values}
					onSwitchVisible={() => {
						changeDrawerState((preState) => ({
							visible: !preState.visible,
						}));
					}}
					visible={detailDrawerState.visible}></DrawerToDetail>
			) : null}
		</React.Fragment>
	);
};
export default supplierApplyList;
