import React, { Fragment } from 'react';
import {
	Table,
	Row,
	Form,
	Button,
	Input,
	message,
	Badge,
	PageHeader,
	Typography,
	Space,
} from 'antd';
import { SearchOutlined, PushpinOutlined } from '@ant-design/icons';
import { ColumnProps } from 'antd/lib/table';
import {
	useSupplierApllyList,
	SupplierApplyStatus,
	useUpdateSupplier,
} from '../../services/supplier';
import ReviewPopup from './components/reviewPopup';
import DrawerToDetail from './components/detailDrawer';

const { Text } = Typography;
const expandDataRows = [
	{
		title: '供应商',
		dataIndex: 'name',
	},
	{
		title: '法定代表人',
		dataIndex: 'legal_person',
	},
	{
		title: '证件号',
		dataIndex: 'id_cert',
	},
	{
		title: '业务联系人',
		dataIndex: 'business_contact',
	},
	{
		title: '业务联系人电话',
		dataIndex: 'business_contact_phone',
	},
	{
		title: '业务负责人',
		dataIndex: 'business_responsible',
	},
	{
		title: '业务负责人电话',
		dataIndex: 'business_responsible_phone',
	},
	{
		title: '紧急联系人',
		dataIndex: 'emergency_contact',
	},
	{
		title: '紧急联系人电话',
		dataIndex: 'emergency_contact_phone',
	},
	{
		title: '企业所属',
		dataIndex: 'enterprise_location',
	},

	{
		title: '业务负责人任命书',
		dataIndex: 'business_responsible_letter',
		img: true,
	},
	{
		title: '法人授权书',
		dataIndex: 'legal_person_letter',
		img: true,
	},
	{
		title: '诚信经营承诺书',
		dataIndex: 'integrity_management_letter',
		img: true,
	},
	{
		title: '营业执照',
		dataIndex: 'business_license',
		img: true,
	},
	{
		title: '审批状态',
		dataIndex: 'statusText',
	},
	{
		title: '审批时间',
		dataIndex: 'approve_time',
	},
	{
		title: '审批回复',
		dataIndex: 'feedback',
	},
];

/**
 * @description 审批 供应商列表
 * @param props
 */
const supplierApplyList: React.FC = () => {
	const [applyModalState, setApplyModalState] = React.useState<{
		modalVisible: boolean;
		id?: string;
	}>({
		modalVisible: false,
	});
	const [detailDrawerState, changeDrawerState] = React.useState<{
		visible: boolean;
		values?: any;
	}>({
		visible: false,
	});
	const [applyListState, requestApplyList] = useSupplierApllyList();

	const [searchState, setSearchState] = React.useState({
		filter: '',
		page: 1,
	});
	React.useEffect(() => {
		requestApplyList(searchState);
	}, [searchState]);

	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};

	const [updatState, requestApply] = useUpdateSupplier();
	const handleSwitchApplyModalVisible = (id = '') => {
		setApplyModalState((preState) => ({
			...preState,
			modalVisible: !preState.modalVisible,
			id,
		}));
	};
	/**
	 * @description 提交审核
	 * @param data
	 * @returns
	 */
	const handleApply = (data) => {
		if (updatState.loading) {
			return;
		}
		requestApply({
			...data,
			id: applyModalState.id as string,
		})
			.then(() => {
				message.success('审批成功');
				handleSwitchApplyModalVisible();
				requestApplyList(applyListState.deepData);
			})
			.catch((error) => {
				message.error(error.message);
			});
	};

	const columns: ColumnProps<any>[] = [
		{
			title: '供应商',
			dataIndex: 'name',
			key: 'name',
		},
		{
			title: '社会统一信用代码',
			dataIndex: 'social_code',
			key: 'social_code',
		},
		{
			title: '业务联系人',
			dataIndex: 'business_contact',
			key: 'business_contact',
		},
		{
			title: '业务联系人电话',
			dataIndex: 'business_contact_phone',
			key: 'business_contact_phone',
		},
		{
			title: '申请时间',
			dataIndex: 'apply_time',
			key: 'apply_time',
		},
		{
			title: '审核状态',
			dataIndex: 'status',
			key: 'status',
			render: (dataIndex, record) => {
				const isRefuse = record.status === 2;
				return (
					<Fragment>
						<Badge status={isRefuse ? 'error' : 'processing'}></Badge>
						<Text type={isRefuse ? 'danger' : 'secondary'}>
							{SupplierApplyStatus[dataIndex]}
						</Text>
					</Fragment>
				);
			},
		},
		{
			title: '操作',
			render: (record) => {
				const isRefuse = record.status === 2;
				return (
					<Space>
						<Button
							disabled={isRefuse}
							icon={<PushpinOutlined />}
							onClick={() => handleSwitchApplyModalVisible(record.id)}>
							审核
						</Button>
						<Button
							type='primary'
							onClick={() =>
								changeDrawerState({ visible: true, values: record })
							}>
							详情
						</Button>
					</Space>
				);
			},
		},
	];

	return (
		<React.Fragment>
			<PageHeader
				title='审批-供应商列表'
				style={{ paddingLeft: 0 }}></PageHeader>
			<div>
				<Form layout='inline' onFinish={onSearch}>
					<Form.Item name='filter'>
						关键字：
						<Input
							style={{ width: 280 }}
							placeholder='供应商名称或社会统一信用代码'></Input>
					</Form.Item>
					<Button
						type='primary'
						htmlType='submit'
						icon={<SearchOutlined></SearchOutlined>}>
						搜索
					</Button>
				</Form>
			</div>
			<Table
				columns={columns}
				loading={applyListState.loading}
				rowKey={(record) => record.id}
				pagination={{
					hideOnSinglePage: true,
					current: applyListState.page,
					total: applyListState.total,
					onChange: (page) => {
						setSearchState((preState) => ({ ...preState, page }));
					},
				}}
				dataSource={applyListState.dataSource}></Table>
			<ReviewPopup
				visible={applyModalState.modalVisible}
				onCancel={() => handleSwitchApplyModalVisible()}
				onSubmit={handleApply}></ReviewPopup>
			{detailDrawerState.values ? (
				<DrawerToDetail
					dataRows={expandDataRows}
					values={detailDrawerState.values}
					onSwitchVisible={() => changeDrawerState({ visible: false })}
					visible={detailDrawerState.visible}></DrawerToDetail>
			) : null}
		</React.Fragment>
	);
};
export default supplierApplyList;
