import React, {
	useState,
	Fragment,
	useEffect,
	useImperativeHandle,
} from 'react';
import { useHistory } from 'react-router-dom';
import { Table, Form, Select, Input, Button, DatePicker, Modal } from 'antd';
import { FormItemProps } from 'antd/lib/form';
import { RouteComponentProps } from 'react-router-dom';
import { SearchOutlined, ExceptionOutlined } from '@ant-design/icons';
import { ColumnProps } from 'antd/lib/table';
import { TaskStatus, usetTaskList, TaskSearchProps } from '../../hook';
import { useProjects } from '../../../../services/project';
const { Option } = Select;
const { RangePicker } = DatePicker;

const taskStateConfig = [
	{
		label: '全部',
		value: 0,
	},
	{
		label: '是',
		value: 1,
	},
	{
		label: '否',
		value: 2,
	},
];
interface Iprops {
	task_type: 1 | 2 | 3;
	ref?: any;
}
const warns: React.FC<Iprops> = React.forwardRef(({ task_type }, ref) => {
	const history = useHistory();
	const [projectListState, requestProjectList] = useProjects();
	const { state: taskListState, request: requestTaskList } = usetTaskList();
	const [searchState, handleChangeSearchState] = useState<TaskSearchProps>(
		() => {
			return {
				page: 1,
				task_type,
			};
		}
	);
	useEffect(() => {
		requestProjectList({});
	}, []);
	useEffect(() => {
		requestTaskList(searchState as any);
	}, [searchState]);
	useImperativeHandle(ref, () => ({
		refresh: () => {
			searchState.page === 1
				? requestTaskList(searchState as any)
				: handleChangeSearchState((preState) => ({ ...preState, page: 1 }));
		},
	}));
	const columns: ColumnProps<any>[] = [
		{
			title: '项目名',
			dataIndex: 'project_name',
			key: 'project_name',
		},
		{
			title: task_type === 3 ? '告警名' : '任务名',
			dataIndex: 'task_name',
			key: 'task_name',
		},
		{
			title: '任务编号',
			dataIndex: 'task_code',
			key: 'task_code',
		},
		{
			title: task_type === 3 ? '告警时间' : '派发时间',
			dataIndex: 'created_time',
			key: 'created_time',
		},
		{
			title: '超期',
			dataIndex: 'is_overdue',
			key: 'is_overdue',
			render: (is_overdue) => (is_overdue ? '是' : '否'),
		},
		{
			title: '任务状态',
			dataIndex: 'status',
			key: 'status',
			render: (_, record) => TaskStatus[record.status],
		},
		{
			title: '操作',
			render: (record) => {
				return (
					<Button
						type='primary'
						icon={<ExceptionOutlined></ExceptionOutlined>}
						onClick={() => {
							history.push(`task/${record.id}`);
						}}>
						审核
					</Button>
				);
			},
		},
	];
	const searchForms: FormItemProps[] = [
		{
			name: 'project_id',
			label: '项目名',
			children: (
				<Select allowClear style={{ width: 150 }} placeholder='请选择项目'>
					{projectListState.dataSource.map((project) => {
						return (
							<Select.Option value={project.id} key={project.id}>
								{project.name}
							</Select.Option>
						);
					})}
				</Select>
			),
		},
		{
			name: 'status',
			label: '任务状态',
			children: (
				<Select allowClear style={{ width: 150 }} placeholder='请选择任务状态'>
					{Object.keys(TaskStatus).map((status) => {
						return (
							<Select.Option value={status} key={status}>
								{TaskStatus[status]}
							</Select.Option>
						);
					})}
				</Select>
			),
		},
		{
			name: 'overdue',
			label: '超期',
			children: (
				<Select placeholder='请选择是否超期' style={{ width: 150 }}>
					{taskStateConfig.map((state) => {
						return (
							<Select.Option key={state.value} value={state.value}>
								{state.label}
							</Select.Option>
						);
					})}
				</Select>
			),
		},
		{
			name: 'filter',
			label: '关键字',
			children: <Input placeholder='任务名称或任务编码'></Input>,
		},
		{
			name: 'time',
			label: '时间',
			children: <RangePicker></RangePicker>,
		},
	];
	return (
		<Fragment>
			<div>
				<Form
					layout='inline'
					onFinish={(values) => {
						handleChangeSearchState((preState) => ({
							...preState,
							...values,
							start_time: values.time
								? values.time[0].hours(0).minute(0).second(0).unix()
								: undefined,
							end_time: values.time
								? values.time[1].hours(0).minute(0).second(0).unix()
								: undefined,
							page: 1,
						}));
					}}>
					{searchForms.map((formItem) => {
						return (
							<Form.Item
								style={{ marginBottom: 15 }}
								{...formItem}
								key={formItem.name as string}></Form.Item>
						);
					})}
					<Button
						type='primary'
						htmlType='submit'
						icon={<SearchOutlined></SearchOutlined>}>
						搜索
					</Button>
				</Form>
			</div>
			<Table
				rowKey={(record) => record.id}
				columns={columns}
				loading={taskListState.loading}
				dataSource={taskListState.dataSource}
				pagination={{
					hideOnSinglePage: true,
					total: taskListState.total,
					current: taskListState.page,
					showSizeChanger: false,
					onChange: (page) => {
						handleChangeSearchState((preState) => ({ ...preState, page }));
					},
				}}></Table>
		</Fragment>
	);
});
export default warns;
