import { Divider } from 'antd';
import { useState } from 'react';
import Request from '../../utils/request';
export const TaskType = {
	1: '质量',
	2: '安全',
};
export const TaskStatus = {
	0: '全部',
	1: '待处理',
	2: '待审核',
	3: '审核退回',
	4: '已处理',
};
export const TaskProcess = {
	1: '创建任务',
	2: '处理任务',
	3: '审核任务',
};
export interface TaskRecordProps {
	id: number;
	project_addr: string;
	created_time: string;
	project_code: number;
	project_id: number;
	project_name: string;
	safety_record_no: string;
	status: keyof typeof TaskStatus;
	task_code: string;
	task_desc: string;
	task_type: keyof typeof TaskType;
	finish_date: string;
	assignment_date: string;
	is_overdue: boolean;
	task_name: string;
	create_time: string;
}
export interface TaskSearchProps {
	page: number;
	filter?: string;
	start_time?: number;
	end_time?: number;
	task_type: 0 | 1 | 2 | 3;
	project_id?: number;
	overdue?: 0 | 1 | 2;
}

/**
 * @description 获取任务列表
 */
export const usetTaskList = () => {
	const [state, setState] = useState<{
		loading: boolean;
		total: number;
		page: number;
		dataSource: TaskRecordProps[];
	}>({
		loading: false,
		total: 0,
		page: 1,
		dataSource: [],
	});
	const request = (params: TaskSearchProps) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/task/list',
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					...data,
					dataSource: data.list,
				}));
			})
			.catch((error) => {
				setState((preState) => ({
					...preState,
					loading: false,
				}));
				return Promise.reject(error);
			});
	};
	return { state, request } as const;
};
type taskDetailProps = {
	finish_date: string;
	task_code: string;
	task_name: string;
	task_type: keyof typeof TaskType;
	list: {
		approve_status: boolean;
		desc: string;
		img: string[];
		person: string;
		pipe_time: string;
		pipe_type: number;
	}[];
};
/**
 * @description 任务详情
 */
export const useTaskDetails = () => {
	const [state, setState] = useState<{
		loading: boolean;
		dataSource?: taskDetailProps;
	}>({
		loading: false,
	});
	const request = (id: number) => {
		return Request.sendRequest({
			url: `/v1/task/info/${id}`,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: {
						...data,
						list: data.list.map((element) => {
							return { ...element, img: JSON.parse(element.img) };
						}),
					},
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
			});
	};
	return { state, request } as const;
};
/**
 * @description 更新任务
 */
export const useUpdateTask = () => {
	const [state, setState] = useState<{
		loading: boolean;
		dataSource?: taskDetailProps;
	}>({
		loading: false,
	});
	const request = (data: {
		id: number;
		reviewer: string;
		status: boolean;
		feedback: string;
		approve_img: string[];
	}) => {
		return Request.sendRequest({
			url: `/v1/task`,
			method: 'PUT',
			data,
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return { state, request } as const;
};
/**
 * @description 新增任务
 */
export const useAddTask = () => {
	const [state, setState] = useState<{
		loading: boolean;
	}>({
		loading: false,
	});
	const request = (data: {
		finish_date: number;
		project_Id: number;
		task_desc?: string;
		task_name: string;
		task_type: keyof typeof TaskType;
		task_img?: string[];
	}) => {
		return Request.sendRequest({
			url: `/v1/task`,
			method: 'POST',
			data,
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return { state, request } as const;
};
