import * as React from 'react';
import Request from '../utils/request';

export const deviceTypeApplyStatus = {
	0: '待对接',
	1: '对接通过',
	2: '对接未通过',
	3: '审批通过',
	4: '审批未通过',
};

/**
 * @description 审核设备类型
 */
export const useApplyDeviceType = () => {
	const [state, setState] = React.useState({ loading: false, dataSource: [] });
	const request = (data: { feedback: string; status: boolean; id: string }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return new Promise((resolve, reject) => {
			Request.sendRequest({
				url: '/v1/device/type_approve',
				data,
				method: 'PUT',
			})
				.then(() => {})
				.catch((error) => {
					reject(error);
				})
				.finally(() => {
					setState((preState) => ({ ...preState, loading: false }));
				});
		});
	};

	return [state, request] as const;
};
export const deviceKeys = {
	offLine: 0,
	onLine: 1,
};
export const deviceStatus = {
	[deviceKeys.offLine]: '离线',
	[deviceKeys.onLine]: '在线',
};
/**
 * @description 设备列表
 * @param options
 */
export const useDeviceList = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: [],
		deepData: {
			page: 1,
			filter: '',
		},
		page: 1,
		total: 0,
	});
	const request = (params: { page?: number; filter?: string }) => {
		setState((preState) => ({
			...preState,
			loading: true,
			deepData: { ...preState.deepData, ...params },
		}));
		return new Promise((resolve, reject) => {
			Request.sendRequest({
				url: '/v1/device/list',
				params,
			})
				.then((data: any) => {
					setState((preState) => ({
						...preState,
						loading: false,
						dataSource: data.list,
						page: data.page,
						total: data.total,
					}));
				})
				.catch((error) => {
					setState((preState) => ({ ...preState, loading: false }));
					reject(error);
				});
		});
	};

	return [state, request] as const;
};
export type deviceTypeStatus = 0 | 1 | 2;

export type DeviceTypeRecordProps = {
	id: number;
	agent: string;
	agent_phone: string;
	appendix: string;
	approve_time: string;
	comment: string;
	created_time: string;
	feedback: string;
	provider_name: string;
	social_code: string;
	status: number;
	type_code: number;
	type_name: string;
};
/**
 *
 * @description 设备类型列表
 */
export const useDeviceTypeList = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		dataSource: DeviceTypeRecordProps[];
		total: number;
		page: number;
	}>({
		loading: false,
		dataSource: [],
		total: 0,
		page: 1,
	});
	const request = (params: {
		filter: string;
		page: number;
		provider_id?: number;
		list_type: deviceTypeStatus;
	}) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/device/type_list',
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					...data,
					loading: false,
					dataSource: data.list.map((element, index) => {
						return {
							...element,
							index: index + 1,
							appendix: JSON.parse(element.appendix),
						};
					}),
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
				return Promise.reject(error);
			});
	};

	return [state, request] as const;
};
/**
 * @description 设备类型详情
 */
export const useDeviceTypeDetail = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: {
			add_apply_info: {},
			test_apply_info: {},
		},
	});
	const request = (id: number) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: `/v1/device/tested_type_info/${id}`,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: {
						add_apply_info: {
							...data.add_apply_info,
							appendix: JSON.parse(data.add_apply_info.appendix),
						},
						test_apply_info: {
							...data.add_apply_info,
							appendix: JSON.parse(data.test_apply_info.appendix),
						},
					},
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
			});
	};
	return { state, request } as const;
};

export type DeviceTypeForm = Pick<DeviceTypeRecordProps, 'id'> & {
	approveType: 0 | 1;
	feedback: string;
	status: boolean;
};
/**
 * @description 审批设备类型
 */
export const usePutDeviceType = () => {
	const [state, setState] = React.useState({
		loading: false,
	});
	const request = (data: DeviceTypeForm) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/device/type_approve',
			method: 'PUT',
			data,
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return { state, request } as const;
};

/**
 * @description 设备统计(用户可视化展示)
 */
export const useDeviceStatistics = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: {
			increase: 0,
			offline: 0,
			online: 0,
			total: 0,
		},
	});
	const request = () => {
		Request.sendRequest({
			url: '/v1/device/statistic',
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: data,
				}));
			})
			.catch((error) => {
				setState((preState) => ({
					...preState,
					loading: false,
				}));
			});
	};
	return { state, request } as const;
};
/**
 * @description 设备统计(用户可视化展示)
 */
export const useDeviceTypeStatistics = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		dataSource: {
			device_type: string;
			online: number;
			total: number;
			device_code: number;
		}[];
	}>({
		loading: false,
		dataSource: [],
	});
	const request = () => {
		Request.sendRequest({
			url: '/v1/device/type_statistic',
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: data.list,
				}));
			})
			.catch((error) => {
				setState((preState) => ({
					...preState,
					loading: false,
				}));
			});
	};
	return { state, request } as const;
};
export interface DeviceTypeProps {
	id: number;
	type_code: number;
	type_name: string;
}
/**
 * @description 设备类型总列表
 */
export const useDeviceTypeTotalList = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		dataSource: DeviceTypeProps[];
	}>({
		loading: false,
		dataSource: [],
	});
	const request = () => {
		Request.sendRequest({
			url: '/v1/device_type_all',
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: data.list,
				}));
			})
			.catch((error) => {
				setState((preState) => ({
					...preState,
					loading: false,
				}));
			});
	};
	return { state, request } as const;
};
