import { type } from 'os';
import React, { useState } from 'react';
import Request from '../utils/request';
export const ProjectStatus = {
	0: '在建',
	1: '完工',
};

export type ProjectRecordProps = Pick<
	ProjectInfoProps,
	| 'id'
	| 'name'
	| 'category'
	| 'manager'
	| 'construct_type'
	| 'create_time'
	| 'location'
	| 'lat'
	| 'lon'
>;

/**
 * @description 获取工程项目列表
 */
export const useProjects = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		total: number;
		page: number;
		dataSource: ProjectRecordProps[];
	}>({
		loading: false,
		total: 0,
		page: 1,
		dataSource: [],
	});
	const request = (params: {
		filter?: string;
		page?: number;
		page_size?: number;
	}) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({ url: '/v1/project/list', params })
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: data.list,
					total: data.total,
					page: data.page,
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
				return Promise.reject(error);
			});
	};
	return [state, request] as const;
};
type corpProps = {
	id: number;
	area_code: string;
	corp_type: string;
	name: string;
	register_date: string;
	social_code: string;
};
interface ProjectInfoProps {
	id: number;
	area_code: string;
	category: string;
	company_name: string;
	construct_type: string;
	covered_area: number;
	create_time: string;
	desc: string;
	end_day: string;
	invest_type: string;
	lat: number;
	lon: number;
	location: string;
	manager: string;
	manager_phone: string;
	name: string;
	price: number;
	project_effect_pic: string;
	project_plan: string;
	project_status: string;
	safety_record_no: string;
	scale: string;
	start_day: string;
}
export interface ProjectProps {
	corp_list: corpProps[];
	info: ProjectInfoProps;
}
/**
 * @description 获取项目详情
 */
export const useProjectDetail = () => {
	const [state, setstate] = useState<{
		loading: boolean;
		dataSource?: ProjectProps;
	}>({
		loading: false,
	});
	const request = (id: number) => {
		setstate((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: `/v1/project/info/${id}`,
		})
			.then((data: any) => {
				setstate((preState) => ({
					...preState,
					loading: false,
					dataSource: data,
				}));
			})
			.catch((error) => {
				setstate((preState) => ({
					...preState,
					loading: false,
				}));
				return Promise.reject(error);
			});
	};
	return { state, request } as const;
};

export const ProjectChangeStatus = {
	0: '待审核',
	1: '审核通过',
	2: '审核退回',
};
/**
 * @description 项目变更申请列表
 */
export const useProjectChangeList = () => {
	const [state, setState] = React.useState({
		loading: false,
		deepData: {
			filter: '',
			page: 1,
		},
		total: 0,
		page: 1,
		dataSource: [],
	});
	const request = (params: { filter?: string; page: number }) => {
		const newParmas = { ...state.deepData, ...params };
		setState((preState) => ({
			...preState,
			loading: true,
			deepData: newParmas,
		}));
		return new Promise((resolve, reject) => {
			Request.sendRequest({
				url: '/v1/project/change_job_list',
				params: newParmas,
			})
				.then((data: any) => {
					setState((preState) => ({
						...preState,
						loading: false,
						dataSource: data.list,
						total: data.total,
						page: data.page,
					}));
				})
				.catch((error) => {
					setState((preState) => ({ ...preState, loading: false }));
					reject(error);
				});
		});
	};

	return [state, request] as const;
};
/**
 * @description 审批项目变更
 */
export const useApplyProject = () => {
	const [state, setState] = React.useState({ loading: false, dataSource: [] });
	const request = (data: { feedback: string; status: boolean; id: string }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/project/change_approve',
			data,
			method: 'PUT',
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};

	return [state, request] as const;
};

export const useProjectSum = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		dataSource: {
			increase: number;
			total: number;
			totalText: string;
			increaseText: string;
			list: { project_type: string; count: number; percent: string }[];
		};
	}>({
		loading: false,
		dataSource: {
			increase: 0,
			total: 0,
			totalText: '',
			increaseText: '',
			list: [],
		},
	});
	const request = () => {
		setState((preState) => ({ ...preState, loading: true }));
		Request.sendRequest({
			url: 'v1/project/statistic',
		})
			.then((data: any) => {
				Number(1).toLocaleString();
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: {
						...data,
						totalText: data.total.toLocaleString(),
						increaseText: data.increase.toLocaleString(),
					},
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
			});
	};
	return { state, request } as const;
};
/**
 * @description 项目类型统计
 */
